@@ -1,5 +1,7 @@
 # __init__.py
+""" the xosc module contains the classes used to generate OpenDRIVE (xml) files. 
 
+"""
 from .geometry import *
 from .helpers import *
 from .opendrive import *
@@ -8,3 +10,4 @@ from .enumerations import *
 from .links import *
 from .generators import *
 from .signals_objects import *
+from .elevation import *
\ No newline at end of file
