@@ -33,6 +33,12 @@ class _Links():
 
         self.links = []
 
+    def __eq__(self, other):
+        if isinstance(other,_Links):
+            if self.links == other.links:
+                return True
+        return False
+
     def add_link(self,link):
         """ Adds a _Link 
 
@@ -190,6 +196,12 @@ class _Link():
         self.contact_point = contact_point
         self.direction = direction
 
+    def __eq__(self, other):
+        if isinstance(other,_Link):
+            if self.get_attributes() == other.get_attributes():
+                return True
+        return False
+
     def get_attributes(self):
         """ returns the attributes as a dict of the _Link
 
@@ -320,6 +332,13 @@ class Connection():
         self.id = id
         self.links = []
 
+    def __eq__(self, other):
+        if isinstance(other,Connection):
+            if self.get_attributes() == other.get_attributes() and \
+            self.links == other.links:
+                return True
+        return False
+
     def _set_id(self,id):
         """ id is set
 
@@ -405,6 +424,13 @@ class Junction():
         self.connections = []
         self._id_counter = 0
 
+    def __eq__(self, other):
+        if isinstance(other,Junction):
+            if self.get_attributes() == other.get_attributes() and \
+            self.connections == other.connections:
+                return True
+        return False
+
     def add_connection(self,connection):
         """ Adds a new link to the Junction
 
@@ -459,7 +485,7 @@ def are_roads_consecutive(road1, road2):
     return False
 
 def create_lane_links(road1,road2):
-    """ create_lane_links takes to roads and if they are connected, match their lanes 
+    """ create_lane_links takes two roads and if they are connected, match their lanes 
         and creates lane links. 
         NOTE: now only works for roads/connecting roads with the same amount of lanes
 
@@ -526,7 +552,7 @@ def _create_links_connecting_road(connecting,road):
 
 
 def _get_related_lanesection(road,connected_road):
-    """ _get_related_lanesection takes to roads, and gives the correct lane section to use
+    """ _get_related_lanesection takes two roads, and gives the correct lane section to use
         the type of link and if the sign of lanes should be switched
 
         Parameters
@@ -659,8 +685,15 @@ class JunctionGroup():
         self.junctions = []
         self.junction_type = junction_type
 
+    def __eq__(self, other):
+        if isinstance(other,JunctionGroup):
+            if self.get_attributes() == other.get_attributes() and \
+            self.junctions == other.junctions:
+                return True
+        return False
+
     def add_junction(self,junction_id):
-        """ Adds a new link to the Junction
+        """ Adds a new link to the JunctionGroup
 
             Parameters
             ----------
@@ -670,7 +703,7 @@ class JunctionGroup():
         self.junctions.append(junction_id)
 
     def get_attributes(self):
-        """ returns the attributes as a dict of the Junction
+        """ returns the attributes as a dict of the JunctionGroup
 
         """
         retdict = {}
@@ -686,4 +719,4 @@ class JunctionGroup():
         element = ET.Element('junctionGroup',attrib=self.get_attributes())
         for j in self.junctions:
             ET.SubElement(element,'junctionReference',attrib={'junction':str(j)})
-        return element
\ No newline at end of file
+        return element
