@@ -11,4 +11,4 @@ from .scenario import *
 from .storyboard import *
 from .entities import *
 from .enumerations import *
-from .catalog_reader import *
\ No newline at end of file
+from .xosc_reader import *
\ No newline at end of file
